;;Before using this program is necessary to import from the existing library the turtle shape "bike"

extensions [gis]

breed [bike_docking_stations bike_docking_station]
breed [people person]
breed [bikes bik]

globals [
  torino          ;; GIS dataset
  center-x        ;; Centering the map by mouse
  center-y        ;; Centering the map by mouse
  platforms       ;; Agent set of Netlogo linked to postazioni dataset
  postazioni      ;; Bike sharing platforms GIS dataset
  streets         ;; Agent set of Netlogo linked to torino dataset
  tot_people      ;; Total number of people created
  counter     
         ]

bike_docking_stations-own [
  bikes_avail_num        ;; Number of bike on a patch
  docks_avail_num        ;; Number of bike docking free
  bikes_br_num           ;; Number of broken bikes
  people_waiting         ;; People waiting for a bike at an empty bike docking station
            ]

patches-own [
  platform?       ;; True if the patch is a bike sharing platform
  street?         ;; True if the patch belongs to a street
  turtles-num     ;; Number of turtles on a patch
             ]

bikes-own [
  destination     ;; Destination of each bikers
  dist            ;; Distance from the destination
  bike_time       ;; The amount of time since the turtle is riding a bike
  counter_touch   ;; It is used to give variability to the path  
  change_time     ;; Time spent looking for a free docking station
  new_arrival     ;; It allows me to count how many bikes have been hired from new people          
             ] 

people-own [
  docking_stations;; Starting point
  destination     ;;
  wait_time       ;; The amount of time wasted waiting for a bike
             ]

;; World 

to setup
  set zoom 1
  clear-all
  reset-ticks
  ask patches [set pcolor white]
  set torino gis:load-dataset "Turin_map.shp"                   
  set postazioni gis:load-dataset "TO_Bike_actual_situation.shp"    
  draw
end

to stations-creation
foreach gis:feature-list-of postazioni [let location gis:location-of (first (first (gis:vertex-lists-of ?)))
                                        if not empty? location [
                                          create-bike_docking_stations 1 [
                                          set xcor item 0 location
                                          set ycor item 1 location
                                          set bikes_avail_num gis:property-value ? "available_b"
                                          set docks_avail_num gis:property-value ? "available_p"
                                          set bikes_br_num gis:property-value ? "broken_bike"
                                          ifelse bikes_avail_num > 0 [set shape "flag"
                                                                      set color blue
                                                                      set size 10]
                                                                     [set shape "x"
                                                                      set color red
                                                                      set size 10] 
                                          ]]]
end

to draw
  ask bike_docking_stations [die]
  clear-drawing
  setup-world-envelope
  gis:set-drawing-color (gray + 1)  gis:draw torino 1      ;; Setting the color and drawing the map of the city with fixed thickness
  gis:set-drawing-color red gis:draw postazioni 1          ;; As above but referred to the platforms
  stations-creation
  meaning
end

to meaning
  if count bike_docking_stations <= 1 [print "Simulation FAILED"]
end

to setup-world-envelope  
  gis:set-world-envelope gis:envelope-of postazioni              ;; Transformation by mapping the envelope of the NetLogo world to the given envelope in GIS space (x and y have the same scales)
  let world gis:world-envelope
  let x0 (item 0 world + item 1 world) / 2  + center-x           ;; Centering the x-axis as the middle value of the borders of the envelope
  let y0 (item 2 world + item 3 world) / 2  + center-y           ;; As above but for the y-axis
  let W0 ((1 / zoom) * (item 1 world - item 0 world) / 2) + 100  ;; The more you zoom, more details appear in the window
  let H0 ((1 / zoom) * (item 3 world - item 2 world) / 2) + 100  ;; Note: the final +100 only needs to include the platforms on the borders
  set world (list (x0 - W0) (x0 + W0) (y0 - H0) (y0 + H0))       ;; The dimension of the world is affected by the zoom  
  gis:set-world-envelope world                                   ;; Final world is set as the envelope
end

to click_into_the_map
  while [not mouse-down?] [wait .01]                      
  set center-x center-x + (mouse-xcor * transformation-gis-patch-size)     ;; Commutation rules to center the map on the pointer
  set center-y center-y  + (mouse-ycor * transformation-gis-patch-size)
  draw
end

to-report transformation-gis-patch-size                 
  let world gis:world-envelope
  report (item 1 world - item 0 world) / (max-pxcor - min-pxcor)           ;; It adapts the distance between two points of GIS to the size of NetLogo's patch
end

;; Streets

to show_streets
  set counter counter + 1
  ifelse int(counter / 2) != (counter / 2) [                                   ;; It allows to turn on/off the "show_streets" button
       if streets = 0 [set_streets]
       ask streets [ set pcolor red]       ] [ask streets [set pcolor white]]
end

to set_streets
  ask patches [set street? true]
  ask patches gis:intersecting torino                                          ;; Reports the patches that intersect at least in one point the given GIS data
       [set street? false]
  set streets patches with [street? = true]
end

;; People and bikes

to add_bikes
  if streets = 0 [set_streets]
  set-default-shape bikes "bike"
  create-bikes num_bikes [set counter_touch 0
                          set new_arrival false
                          set size 15 
                          move-to one-of streets with [abs pxcor < 225 and abs pycor < 225]
                          set destination one-of bike_docking_stations
                          set heading towards destination
                          pen-down]
end

to add_people
  set-default-shape people "person"
  set tot_people 0
  create-people num_people [set size 10
                            set docking_stations one-of bike_docking_stations
                            move-to docking_stations
                            set destination one-of bike_docking_stations
                            while [destination = docking_stations][set destination one-of bike_docking_stations]]
  ask bike_docking_stations [set people_waiting (count people-here)]
end

;; Movement

to go
  bikes_movement
  people_movement
  setdist
  tick
end

to borders_b
  ask bikes [if (abs xcor > 228 or abs ycor > 228) [move-to one-of streets in-radius 10 with [abs pxcor < 226 and abs pycor < 226]
                                                    set heading random 360]]
end

to bikes_movement 
  borders_b  
  ask bikes [ifelse int(counter_touch / 2) = (counter_touch / 2) [ifelse ([street?] of patch-ahead 1 = true and dist > 15) [set heading towards destination
                                                                                                              fd 1
                                                                                                              set bike_time bike_time + 1]
                                                                                                             [fd -1
                                                                                                              set heading (heading + random 360) 
                                                                                                              set counter_touch counter_touch + 1
                                                                                                              set bike_time bike_time + 1]]
                                                                 [ifelse ([street?] of patch-ahead 1 = true) [fd 1
                                                                                                              set bike_time bike_time + 1]
                                                                                                             [fd -1
                                                                                                              set heading random 360 
                                                                                                              set counter_touch counter_touch + 1
                                                                                                              set bike_time bike_time + 1]]                                                             
            ]
end

to setdist 
   ask bikes [set dist distance (destination)]  
   ask bikes with [dist < 15] [move-to destination
                            ask destination [ifelse docks_avail_num > 0 [set bikes_avail_num (bikes_avail_num + 1)
                                                                         set docks_avail_num (docks_avail_num - 1)
                                                                         set shape "flag"
                                                                         set color blue
                                                                         set size 10
                                                                         ask bikes-on self [die]]
                                                                        [ask bikes-on self [set destination one-of bike_docking_stations
                                                                                            set change_time change_time + 1]]
                                            ] 
                           ]
end 

to people_movement
   if streets = 0 [set_streets]
   if count bike_docking_stations with [people_waiting > 0 and bikes_avail_num > 0] > 0 [ask bike_docking_stations with 
                                                                                                   [people_waiting > 0 and bikes_avail_num > 0] [set people_waiting people_waiting - 1
                                                                                                                                                 set bikes_avail_num bikes_avail_num - 1
                                                                                                                                                 set docks_avail_num docks_avail_num + 1
                                                                                                                                                 ask people-on self [set size 15
                                                                                                                                                 set breed bikes
                                                                                                                                                 set new_arrival true
                                                                                                                                                 set counter_touch 0
                                                                                                                                                 pendown]]
                                                                                         ]
   if count bike_docking_stations with [people_waiting > 0 and bikes_avail_num = 0] > 0 [ask people-on bike_docking_stations with 
                                                                                                       [people_waiting > 0 and bikes_avail_num = 0] [set wait_time wait_time + 1]
                                                                                     ]
end
@#$#@#$#@
GRAPHICS-WINDOW
210
11
681
503
230
230
1.0
1
10
1
1
1
0
0
0
1
-230
230
-230
230
0
0
1
ticks
30.0

SLIDER
16
149
196
182
zoom
zoom
0.5
7.5
1
0.25
1
NIL
HORIZONTAL

BUTTON
63
30
126
63
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
32
91
174
124
NIL
click_into_the_map
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
63
209
126
242
NIL
draw
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
7
10
157
28
1st step: create the world
11
0.0
1

TEXTBOX
7
69
204
87
2nd step: choose the area to analyze
11
0.0
1

TEXTBOX
7
129
157
147
3rd step: zoom the area
11
0.0
1

TEXTBOX
8
189
158
207
4th step: draw
11
0.0
1

BUTTON
16
292
191
325
NIL
show_streets
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
8
246
199
288
Facultative: it shows which patches are considered as streets. Click it again to bring it to normality.
11
0.0
1

BUTTON
119
371
206
404
NIL
add_people
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
3
331
117
364
num_bikes
num_bikes
0
150
50
1
1
NIL
HORIZONTAL

BUTTON
119
331
206
364
NIL
add_bikes
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
3
371
117
404
num_people
num_people
0
20
20
1
1
NIL
HORIZONTAL

BUTTON
63
411
126
444
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
692
11
892
161
N° of total bikes
Time (ticks)
N° bikes
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count bikes"

PLOT
692
315
892
465
N° of people waiting for a bike
Time (ticks)
People waiting 
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count people with [wait_time > 0]"

PLOT
692
163
892
313
Levels of distances
Far    -    Middle    -      Near
N° bikes
0.0
10.0
0.0
10.0
true
false
"ifelse count bikes > 0 [set-plot-y-range 0 count bikes][set-plot-y-range 0 1]" ""
PENS
"Far" 3.3 1 -2674135 true "" "plot-pen-reset\nset-plot-pen-color red\nplot count bikes with [dist >= 300]\nset-plot-pen-color yellow\nplot count bikes with [dist >= 150 and dist < 300]\nset-plot-pen-color green\nplot count bikes with [dist < 150]"

PLOT
894
315
1094
465
People who found a bike vs. people who did not
Riding       -       Waiting
N° of people
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 5.0 1 -16777216 true "" "plot-pen-reset\nset-plot-pen-color blue\nplot count bikes with [new_arrival = true]\nset-plot-pen-color red\nplot count people with [wait_time > 0]"

MONITOR
894
268
1094
313
Max distance
[dist] of max-n-of 1 bikes [dist]
17
1
11

MONITOR
894
105
1094
150
Max n° of "crashes" against walls
[counter_touch] of max-n-of 1 bikes [counter_touch]
17
1
11

MONITOR
894
58
1094
103
Min n° of "crashes" against walls
[counter_touch] of min-n-of 1 bikes [counter_touch]
17
1
11

MONITOR
894
221
1094
266
Min distance
[dist] of min-n-of 1 bikes [dist]
17
1
11

TEXTBOX
898
10
1093
66
The number of \"crashes\" represents the exact number of times the biker has changed his direction.
11
0.0
1

TEXTBOX
896
163
1094
233
Comparing the distance and the time (ticks) one can verify that agents are affected by the \"kind\" of the street. As it happens in the real world.
11
0.0
1

MONITOR
1096
315
1296
360
Time waiting for a bike
[wait_time] of max-n-of 1 people with [wait_time > 0][wait_time]
17
1
11

PLOT
1096
11
1296
161
Active / Empty bike docking stations ratio
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 5.0 1 -16777216 true "" "plot-pen-reset\nset-plot-pen-color red\nplot count bike_docking_stations with [bikes_avail_num > 0]\nset-plot-pen-color yellow\nplot count bike_docking_stations with [bikes_avail_num = 0]"

PLOT
1096
163
1296
313
Change in destination
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 5.0 1 -16777216 true "" "plot-pen-reset\nset-plot-pen-color red\nplot count bikes with [change_time = 0]\nset-plot-pen-color green\nplot count bikes with [change_time > 0]"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bike
false
1
Line -7500403 false 163 183 228 184
Circle -7500403 false false 213 184 22
Circle -7500403 false false 156 187 16
Circle -16777216 false false 28 148 95
Circle -16777216 false false 24 144 102
Circle -16777216 false false 174 144 102
Circle -16777216 false false 177 148 95
Polygon -2674135 true true 75 195 90 90 98 92 97 107 192 122 207 83 215 85 202 123 211 133 225 195 165 195 164 188 214 188 202 133 94 116 82 195
Polygon -2674135 true true 208 83 164 193 171 196 217 85
Polygon -2674135 true true 165 188 91 120 90 131 164 196
Line -7500403 false 159 173 170 219
Line -7500403 false 155 172 166 172
Line -7500403 false 166 219 177 219
Polygon -16777216 true false 187 92 198 92 208 97 217 100 231 93 231 84 216 82 201 83 184 85
Polygon -7500403 true true 71 86 98 93 101 85 74 81
Rectangle -16777216 true false 75 75 75 90
Polygon -16777216 true false 70 87 70 72 78 71 78 89
Circle -7500403 false false 153 184 22
Line -7500403 false 159 206 228 205

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
